
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00y\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02e\x03d\x01'
        b'd\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadedsT.\x00\x00PYARMOR\x00\x00\x03\x07\x00B\r\r\n\t4\xe0'
        b'\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x14.\x00\x00\x00\x00\x00\x00\xc2\xf1Y\xc3m\xac\x83$\xe4\\\xc6\xc1\xce\x95\x93\x1f\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf2\x8f\x02\x1eE\xf1'
        b'\xfa,A\xaf\x82^`9\x84VY\xa0_~\xa2A+1\xcf\xe6is\x858q\r\xa1\xbaX/\xa0\xd2GI\x9a\x99\xd6[\xa7\xff*_\x88.\xefy\x1d\x16\x94W\x91\x85\xb1^Z\xf0\xb4]X\xf0\xe2\xd4\xea\x13'
        b'\xc6y\xbfD1\xde?\x9bq5\rwJl\xf0\xa3\xa3\x91|\xbaY_Q\x1fe\xac\xfaY\xa4\x1f\x0f\xae\xea\xa1\xfbb\xcc\x8a~\xa8\x02J\x80\xe3\xb5\xddP\x92\x9c\x18\x89W\xd7\xd5\x19\x0b\xa8\xffi\n\xb6\xcc\xff\xe1'
        b'\xe3\xe4[\xd4\x9ez\xa1e<\x187\xd2A3v \xf2x\x05y3\xba\x06\xe8<w\x06\x9b\x15"\xa6\xe2\xb5U\x1e\xf7\xf8\xa0De\xa3\xefV\xfa\x94\n\x88l\xc1o\x05\xc8\xc0V\xb8\xfc*\xa3}\x9f^|7\xcd'
        b'/\x9a\x14\xad\xebq\x12\xc7H\x1b\xf3\x95*\xa4F\xdcw\x9bm_\xf3=\xb0(\x13]\xd8\xcf\xaa*F\xac=\xf8\xf1\xc7\xf2\xecx=H8\x14\xd7k\x18\x00d\xe9\x960J\x90\x13\xf1\x08\x82H\x18\xbd\r\x92\xc6\x0b'
        b'D\xf2"\xc6\xda8k\xb6\x02\xdf\xe8\xc3\xac\x17c}\xf0\x13\xb7\xb7\xc9v\xf4\xef"\xab\xc1\xca\x03G\x08Ye\xe2\xcb\xdd\x996\x14\x89B\xf0\xf2;\xb8\xa4=\x19\xd6\\W\xec\xf5Ti\x16\xf4\xa3\xa0\xbb\xa20\x94\x1f'
        b'u~{\x97\xec\x02\xe7\xd9\x80N\xc8\xfe\xfb\xec*\xbf\xf99\x8c\xed;\xce\xd6\x8dW\x89\xdc[u\xc6\x10\xd92\xe5\xca\xf9\xdc\xdeI\x9b\xc2\xb2%\xe4\x93\x81tK\xcf\x9d\xdb}\x08`\xe5\x82*\xa7\xee\xac1\x8d!\xa0'
        b"]\x93j3H\x91\xd7\x0bLiq\x0e'Y[gI\xab\xcaPce.;\xce\xe3%\x17\x820\xd2y\xe8\xc4L\x9d\x9a\x8d\x9dB\xe1\x85d\xc1\xa69\x98\xb4\xb0|r$\xa5\x88\x0e?\xffYQ>\x7fM3\xa0"
        b'!\xeeN\xb9d\xa9u\x85\x96\x9a;\x8d\x0f\xa7F\xd70\x83\xb5\xb7\x06{t\x96\xeb32\xe7\xa0\xe6\x0br\x10\x99#\xf9c\xcf@a\nY@z\x88\xbb\x90N\xfb\xff\x11\xa8\x9a\xa4pL)\x9d\xd5\xd6\x94y\xd0\xbd'
        b'K\xf0\x13\xcd\xe2\xd8H\xe4\xbb\x86\x1d\xa9\x86z\xf8\x92\x16\t\xe9\xf07\x95\x9d\xce\xf8\x81\x0f\xd8\xab\xe2"\xa2\xb0nqq\x1bp.\x93\x06z\xd1\x8f%\xd5\x8f\xa2^\xb9\x8a\xe5\xdaD$q2\xfd\x13\xe3F\x92\xa4\xff'
        b'\xef\x0f\x98\x8c\xfc\x86c\xa4\xe5\xc56j\xbe\xefD\xe3\x13J\xe9\x0c\x9d;\x07g\xec\xde\xf2\xc4H\x8b\xfb\xb5f\xf8\xea\xa8\xbe\xf6\xedz\x97\x89v\xa10\x9c\x0f\xda_g\xf7\xac\xce{\xa1K\xfc\xbe\xc6{,X\xc2\xfc'
        b'\xcf\xf6U\xb8g\xd7\xcf^a^\xaa\xa6\xa1\xb0\x82s\x9e\xbfG=7Z>\x8f\xf5\x91V\x1e\xdb?\x9b\x1f\xc2Ot\x8c[\xb0\x98)\xa1+k\xfcY\xf6\x80\x0c\x9aD\x84\xdepq \x83\x9e\x89\x96-d\xfb<r'
        b"\xe5\x96\x7f\xfe0%Zhx\x89\x13y8\xb8(\x80\x18\x8d\x8c\x8f\x99\x07\xdbeW\xca'3\x8c=qgr\xe9R\x13\xa0\xcd5\xceo\x07\x81\x85H\xc0\xde\x03\x18b^&\xe4\xc0-\xfd\x05,Q\x05\xf3\xb2\x8e\x90"
        b'~\xaf\x83:\x8d\xb7\'\x89\x18?\xd2\x0f\xb020\x0f*\xd8\x86\x08\x9dc \xb6\x18y\xad\x88*\x17\xefz*"\xa1\xe7v\xd3\xf0\xc1*\xf1p\x83C\xd7J\xcc\x05G\xc9B\x86\xf1\xff\x8f@\x86\x89\xbf\xb9\xda\xde\xce'
        b'V\x923\x8bI\x89k\x8dy\x8e\xd8dVbs\xb2`y\xf2d\xd1\xccn}\xf4\x07\xbd\xf8SrQ\xc3a\xa8"\xdc\tdJ\xfa\xf3\x9d\xab.\xbf~\xf6\xae\x8f[\x1fw\x19\x8b\xf1\x7f<\x8a\xf8s3fD\xf3'
        b'\x05\xb0\xc2\xa6\xf8\xd1{\xe1\x9f\xd7\xd1\x02_!\x1fr\x96\xee\xab\xcc\x93\xd4\xc0\xa3Q\x03\xfbRU\x0f\x19\x9d`\xe8\xc3\xa2/\x7f\xab\x1a,O\x96z\xa3\x8d]\x91\x197y\xeei\x92\xfd\xe1k(\x13\x1c\xf2\x11`\x16'
        b'\xe5D\x91\xca\xe3\xefg\xab\xe0y\x99\x97\xcfy\xf5!\n\xa0 \xcaq\x86\xa6T\x93|\x9b\xca\x11\xa46\x01e\x85\xc7Q\xbc\xa7\xc8\xb7x\xbd\x91,\xe4\x1c\x08\xc5L\x85\xd1\xb3]O\xa9\xd8#\xcf\x9e}\x17l\xd7\xf2'
        b"t6\xb19\x1b\xbf\xb7\xd4\xb6\x0ft\xa8x\x1d\xa8 \x01x\x17\xe4\x98;\x93a\x9br'\xff|'\xf7\xd9\xe5\x05D{\x97\x8b\xf5\t\xfe\x9b\xd8O\xeb{\tR*\xe0\x10\xf1Hp'\x87\x93O%\x93\x86j\x94\xa0"
        b'\xefBc\xbb#n\xd4\x90\x19\xed\x10\x08\x18\xe3%\x84\xf0\x02\xbc\x00\xee\x10\x8aWn\x0c\x82\x91p\xc5\x00\xa4\x05\xcc\x14\x16r\x9af\x15\xc6\x8az\xe0\xd3\x8d}\xc6\xb0\xd3[\xc6.\xea\x97\xd0E\xd1\xdbtW\x86\x01k'
        b'.\xa4Q\xe1$\xd3\x0c\x03N\xc7N\xa2\x86\xe3\xb8!\x8aD\xe2(4\x8dV\x94l\x9e\x99\xfcW\xea\xff\xbf\x7f\x82W\xed\n-\xf8\xa9\xee\x89\xec\xad\x9a\xb5\xce\xfce\xd7\xbb\x81Q\x90\x0c\xd5&\xcf\x0c\x14\x9ec\xc8\x9a'
        b'\xcf\x81Eu\xfc\x06\xa9\xc6\x00V\'\xe0S\xe69e\x9d\xcdG\xe3\x9e\x97\xd0\xcd\xad\x15s\\\xc5.\x18\xe6\xfa\xbb"\x10t\x14\x7f\x8b\xec\x89\xe0\xff(\xb6\xf9s"\xfb\x9a\x8a\x17\xae{\xecZ\xdf\xf5\x81\x84H\xfa\xb3'
        b"EY6S\xf2\x85=\xc2\x9a\xc4c\x0e\x95%;\x1b\x14\x98\xa5\x92f'\x1b\xbd1U\x98\x8d&\xbc\xf9\x1b\xa5\xc1\xb06\xb8\xf0I\xd0\xa6\xe6\xe3\x9b\xb7pU\xbc\xbe\xd0x^34\x7f.;\xbf \xc4\x96W\xf8z"
        b'\xb7\x85F\xb8s\t\xf0~`\xb4\xd4I\xef\x80\xc9\xf3\x14s\x0ed-W\x8eP\x9c\xc79\xcd\xa7a\xfe\xb2\xc2{\x04\xee\xe3\xe3\xa1\xddQN^\x0f\xe4\xc2q\xe4NF\x86\\\xcc\xd9\x83\xf7\xbe\xeb\n\x9d\x1f8\xda\x8e'
        b'\xda\x9a\xdc\xd9S\x07Zm\x04E\xeb\x9f^\xcav\xe1!x\x98\tL\xcd\x17\xdd`\xac\xbc\xdf\xe2|\xff\x9e@\xefL>e[\x94\xe0\xabs\xc7\xf2\xe7\x898Z\xd6\x03\x93j\xa9\xc5\x82\xd4\x0c\xd8l\xfdU4\xe7f'
        b"'\xd0\xe1\xde\x85<v\xf7\x80\xa2\xb6j\xcc\xbe\\AL~00\x82\x96\x8f\xa9\x86/Ap\x8a\x9a\x01\x06\x11h\x87=|C\xb2\x00);\xcas\x81\xfd\xb1F;\xbf\xc0\xd6\x86\xdb\x88\x0c\xe2\xc0u-M\x12\xe0g"
        b"\t\x97\xf4\x16\xbd\x18\x03='j\xe6u\xa3\xbc\x8d\x1d\xc1\xf6\x16r}\xec\xab\x07\x88\xfa\x1a[\xce\xab\xbbU\xe9\xdc>\xc9\xb2f\x99\x8c\x13\xaa\x81\xe5l\x03\x02\x97\xde~\xc2^\x1c\xf8c\xd6!:\xe9\x9d\xec\xb3P\xc8"
        b'K\xd6*\xd1b36\x12\xc2q\x19\x9ff+y\xd9\xdc\xc7\xc4\x12X\xc9\x0b\xb2\xf4\xa3+\xeek\xf0\xb3Q\x0e1\xc0\xce\xbd\x8e\x14\xcf\x91\xd3b\x02/\xc4,(!y\x9b\xb7Y\xef\x1c\xa5\xa8I\xd7\xb4W\x8dl\xeb'
        b'\xe4\xcb4$\xf9\xf5\x8b\x95\x00\x93\x1bhr~D\x99\x1e\x1c8\xe1\x1f\x87;\x0e\x1a\xe2\xca\x04[\xe3\x91\xb3\xcc\x0e>6\xc6\xca\x8e\xa2 \x1ay\x958\\@;n\x94\xd9\xe1`\x92\xc5\x8b\xd7j\xe51mt\xbb\x0e'
        b'Y\x1c\x17\xc9\x1d^\x1a\x91\xc8\x14\x86\x84p\x99\xf8#\x98+\x06\xa8~\xc6+\x81\x8d\xb0\xa9\x95g93o%x\xce\x02gqM\xaaX\x9d\ti\x9f\x8e \x91\xfe\x88\xa2\x8a\xaf\xdf\xef\xea&\xfa~\xfc\xf3\x16\xe7P'
        b'\x03\xe3\x93&\x08K\x1di\x1c"E\xc6V\x9e\xf8>:\x97\xad\xf8\xa3E8\xf7\x0e0*\x89A\xb3\xff\xfdD\n)i7F\x84\x88w\xa3wq\x91"\xe2.\xccOs\\6)\xd9a\x13;j\x03\x8e\x16\x8d\xe2'
        b'\xb8\xf6^\xc0\x86\xb9\x0ct\x8a\x19<\xea\x86\x89\xd6\x05\xbd\x82n\xfc\xf3I}S\x83~\xb5\x88|\x90\xc2\xd4L\xf8\xd7\n\xe8\xd4d*\x12W\xfb\x97\xe7\xdb\x86*L?.@\x92\xf9".\x99\xfe\xda\xa8: \xfc\xb2'
        b'\x15\x9bS{g\x1e"\x11nho\xdd\x97>!]t\x9e<.0*\xb0\xd7\xacY\x1bG\xdf\xd9@X{\xc3\xd9\xefN\x13\x12\xb8\x10.\xb32\x05\xdck\xda\x13\xfff0\xe7iWM`\x9e\xc8\xf9\x80\xdb\'\xb7'
        b"-|\xcf\xde\xc6\xfc\xcf\xaa\x8c\xdd\xa0mi\xba-H\xfcM'D\x8d\xc1Z\xe3:FG\x99|\x07\x1b\xe4\xd1w\xad\x96A\xbeO\x96\xac\xbamB\x99/\x84\x81\x1b\xff\xeb>\xcf\xaf]\xfa\x954\xb2E\x8c\xbb\xa6\xc8"
        b'\x89\x06\xbb\xa4jl}\x9eG{\xe63\xf8\xdb\x1f\x91E\x17[*\x83\xb8_\xf4\x83m9y\x92\xe5EY\r]H\xd3\xfcT\x9apX?\x87\x00\xdd\xe3\xfa\xe8\xcb\xef\xfa!\xea$!J\xab\xa5\x02\x81\xd1\xbcv9'
        b'\x0e\xee\x8d\xab\xb9\xca\xbc,\xf9zP\xcas\xdep\x02\xf5a\x1e\x00\xd3\x94\xaa\xd9\xcd5\x07\x8cF\xac\x83\xd6\xbcY\x8dt\xcc0\x8e\xba\xa5)\xfb\xa2\x8d]\xe4\xe8\xe9\xb1z\xaf\xc1\xd0K\xe2\x80\x1cw\xe3\xb80tI'
        b'JR{\x97L\xabU\xe8\xa5PE\x86d*\xadS\x0f\xf9\x13)\xe1{\xd6"\x9b\xb9\xf8{\xd7\xf3\xbd\xae2\ty~\x99J\xe8\xeaw\xbf\xe8\x1c\x90\xfa\xa8\xe9A^\rC\xc6\xeej\xf1\x144@\x84\xb5\xa5\xf3n'
        b'\x8d\xa6\xa2\x08\xa8\xf8\xba\x15}\xbc\x8d\xca\x14\xc7\x13IQ\xf8\xf0\xd6\xdc\xf8\xb1"\x89\x91\xa7\xd1\xe0[\x16\xd0\x85:\x9b;"\x13\xb1\x98T),\xedLZ\xb4\xbb\xc1\xee\xc3\x9fN\x91\xfe-d1q\xa0\x84\x0e>\xaa'
        b'K\xeb\xf1\xcc\xd4\xde\xdd& \xfa\x9a\x9b\x07]\xfb\x07\r\xd6\x91\n\x8a\xdf\x19~\xb1C\x9efg\xfd\\\xdc\xc6\x1el9\x95,\x92\x022\x8c\x89g\x8e?F\x0ek\xe2\x9dD&x\xe3\xaa\xf8\xbd \xff\x15\x8b\xc2\xac'
        b':1*#\xad\x06\x92=[\x82\x1d\x98\xf1\x83F\xfd\xa2\r\xbe]\x80~\xe58%\xef-r8\xe1\xaf\x97\x9b\x9d1N|@\xfcIyg{\x10\xab\x89\xd5\xe2t-\xdb\x0f\x84^\x99\x84\x04\r\xf2\xd5\xc0\x1et:'
        b'H\x18\xa3\n~\xbe\xd9\xef3\x07\xb8r(O\xb8J\xd3L\xbe\xc5\xc1\xcd\x81\x17\xaahpI\x00\x977\x1a\x8f\xbc\x8e\x17\x94\x0c\xd8>U\xc7\xf84ol>\xcf*\xda\xfbS\x1a\x94\xcd\x90\xd7\xbd" \xa3[?\xce'
        b"K\xfe\xab)k\xbaF\xe1\x1b>[K\x8c]\xa8\xae\xcc-\x8b\xca5w\xd6\x93\x13\xcfI\x85\xc87\xc4\xe0\xd51\xf2(5\x11\x9d\x88\x9f\xe3\x80+\xf4K\x1a\xba\x17\xad\x7f\x079W\x1d\x80;S'\xdaP\x127\xe2"
        b'\xd4Tt\xdc\x1btfw\xe1g\xcd\xf1\xbd\xed\x1bX\xdb&U%\xf1\x07\x1c,\xce\xe5B\x96\xacE\xf5\\P\xb3\x16S \n\\\xf4\t\xaa\x9e\x93?\xb1\x91yc\x1a\x8b\x0e\xffF\xbb\x10K\xb7\xb66C\xfdS\xe4'
        b'\xd0\x8cNQ\xeb\xad\x94I\x8e\x7f\x08\xb2\xea\xcb\xbc\xedo\x1c\x08.y9}\x85%\x11\x12+\x1be!\xb6\x00\xef\xb2\xf1\xab\xaeyO!\xdfd\x145z\xce\xef\xc9\xab%\x17\xa3]\xff;"\xecQ<\xe5\x18\x04\x96'
        b'\xdc7,R\xda\xc2\x95J\x1b\xf04E\x9d\xb0(\xd4K\xb29\x02\xe8DW\xb6\xbb\x1c\xf1lv\x08i{\xea\xfd\xb4J\xee\x0e\xd8L\x90\xc1\xce`\xe9\xad\xf6@f)E\x01\x0b\xf3`a\xe7\x9b\xe6l\xdc\xa9\xb4$'
        b'L\x9fK\x1b\xa6\xbd\x96\xee\xe6~q\xfd5\xdfpO+X\xb8\xf8PK\x94\xed\x03X\xeb\x08\xfd\x0f\xa1\xda\x8a\xc6VF\xbf\xc0~\xfaa7\x9d\x89\xc1\xcc:2\x19\xd4\x83\xb1;\xcb\xb6uvK\x0c^\x89\x14\xacE'
        b"\x97\x17-#\x7fN\x86\xdd\xe0\x05<\xd1H wny\x9f\x1b\xaf\xbb]S\xde\xfb\x82\x06\xdc1\xef\xfbyf\xce\x02\xeb\x82\x85)\xbd&9R\x97\x0e\xe8\x8a\x9f\xd2\x83@a/\xe6'\xbaQ1\xe3G\xa6\xab\x88\x92"
        b':\xde\xb18\xbd\x16\xc2\x7f\x1c\xbe\xde3*h\xdef\x8d\xed\xdf~\xd3tmS\xea0\xa2\x84A\xc4\xe5\x1bC\xacZ;\x8do\xed\x81VM\xb3\x8c\xf5\x00\xb8\x02\xcd\x1a\xd9\xae&!&\xf2=\x95\x93\xe2\xd5-8\xc0'
        b"X\xbe\xce+\t\xce\xa1\x1f\xf2Xk\x92\xf7\x0e\xae\x0f\x0bRV\x92^\xcc9\xb4\xae8\x87\xcc\xe5\t]\x86-|Z$-\x8a'-\x02z\x87Z\xa7\xf42\x83\xa5\xbcHp|\xcaU\x99^W\x81G\xd3\x14\xff>"
        b"\xac\n\xe4\x99'\x98/,Q{\xe5\x94]\xa80!\xfb\xdc\x15\xfc'\xabh\x01\xad\xfe\x8bv}!\x07\xd5\x19\x089D\n\xafO\x07\xd6l\xc5{(\x96I\xfd\xcf\\\xc2\x13\xd3\xbd\xe4E\xe7\xd8\xde\x19<\x99d/"
        b'j}7\xde\xd2&[\xae+\xcb\x12j\xce\xc1Q\xbe\xf3\xb1:\x01\xf0\x9f\x95l\xe7\x97\x98\x02\xb6\x07\xf6\xde:G\x15\xeb\x12_\xbc8\x13\xe0\x94c\xe3\xe7^\xbeW\x8e\xc72=\xba\x181\xa3\x8c8;\xd6\xe2\xe4\x1f'
        b'a\x18\x86\xf5\xde\xbbQ\xb2\x9d\xbe.\xc6\xecO\xd9\xf9\xfa\xefh\x1e\xf6\xaa%\xf0"~`\xbe\n\x82;\xc0\xe2\xa2\xde\x83\x19\x92\xa9[`sQ\x1c\xfb\x15\x8cZ(\x18\xd9\xea\xb8J\x06h\x1c\xb0\xdem\x9c\x80\xb5H'
        b"~\xf4\xf5\xada\x89\xdc2\x10Ju\n\x9e3A.1\xd6\xfa\xbe\x8d\xd1\xc0\xec\xe5kh\x86k\x1e\x97\x8a\xf0\xfa\xff\x08v\xc3E\xf8\xea\x97S\xb7'&2\xb1\x0e\x0f\x1a\xd3\xd6\xc4\xea\xf7\x91\xca\t\x02((\xf8\xb5"
        b'&\xc8\x00\x0f\xcd\xcf\x06\xb5\xd9o\x07\x0f\xddT\x11\xc0]>pEP#\xee\r\x9c\xaa\xa9\x07\xd2M\xdd\x1c\xa5\xaf\xc4\xb4\xa8R\xe6H\xaa\xa3\xd50 y\x1d[\x10\xc9\xd4Yq\x8d\x94&i\xaf&%\xb9$J\xc1'
        b'\xac>t(\xa2fW\x99\x11^\x1b.\x00\xda\xa4A\x14jc\xeb\x9d\xb3\xf3u\xb9\\IenH8\xf0\xe8\x07\xfeWoA\xb0\xe7S{\xbb\xd6&2\xdb\xa4]~rA\xa2J\xfa\xbb\x0f\xb93t4\xd4\x9dN'
        b'!\xda\x136\xbc\xe1\xe9\x0e\x92\x91\x1c%\xe8\xa6;\x02mu\x0f\x96\xf4fc\x89\x1dC,\xb8gV\xb5\xf7\x1f:\xd9\xdeg\xf6\x87,rS\xf6Z\xe6\xd7\xa4IE\xbd\xdf\x81\x90\x0e6\xbd\xcdJ\xd0V\x1c\x97\x14\x00'
        b'\xb1h\xc2\xdd\xc6\x19\x12F\xc7LP\xfbBHJ\xd9m\x1a\xderPH\xb7\xa31\xbc\xa8`\x9f\x1dhvM)\x12R\xd3)\xd7\x8aKs\x91\xed\x07\xd5\xb0\xa4\t\xe7\xa0\x08\xed\xaa5,\xd7\xe5\x1c\xa8\xe6\xb6\x0c['
        b"X\xca\x92\xe6\x01\x0e\xf0\xd6oYd\xe7F\x0e-w\xd8\xdeh\x19Q\xbcX'\x1f\xee`\x0e\xba1\x95\xbfs{\xb6\xb0\xd84\xe8\x91\x7f\xd1\x9ak\x05\xea\x11\x8f\x8f\xce(\xe7\xa8\xe0K\xea\x83H\xf0\x95\t\xe3E\x93"
        b'\xce\xcb\xb8\xba\x1a\x1c\xff\x8b\x18\xfb\xfb~\xa1\xadz\xe0\xb7\xe1\x94\x9b\x92F\x02?s\xd3\xc4\xc0\xaaVa\xc5Z\xee@\xf4f,#>\x04h\xb5\xc2\xed"08\xda\xd1h\x84S\xe1G\xa9\xa0\x12\x7f\xe8\xb1%\xaa\xc9'
        b'\x15?\x1a0sG\xae55\xe2\x14\x94\x9e5\xc1"\x05\x11,\x90\xcb\xfdR\xf3\xa1\x92\x87B\x1f\'ye\xccM&Du\xab1\xef\xa5Z\xd1\xbd\xf4\xab~!\xb7\xbb\xae\xfe\xf9\x8b\x04\xee\xa6\t\xfe\xb5x\xb0\x8cI'
        b'\xe1\x06p\xdd\xd5*><\xc3\xd3I\xf7W\x18\x9f\xc3}\x17\xb2t\xe9&\xfc\xa3\x8d,f\xaa\xc7\xddY>\x90\\\x19!\x8d!\x02\xc6\xb1\xf8OO)\xab\xb1\xbfaX\xb9\x95\xe8u\x8c\xd6\x1c\x0f\xb3\xc4F\xef\xf1\xae'
        b'\xc2\xf1\rC\xf6S\xf2D\x19\xda{\x11&\xf8Q\xca2[9\xaf\x8e\xcaJ\xb8\xe5\x1a\x9e\xbc\x8eh]\xdb(\x87"\'\xf7\x14\x99&\x11\xf8jq\xa9\x10\xbaH\x0b\xb9b\xf3\x90{\xd1G\xd3\xaal\xe7\xd2\xa2?\xf3'
        b'\x08\xc6&\x0c-\x04\xba~\x15\xdd\xb1\xae\xbc\xd4\xaf\x0b)\xc1\xb7%FO\x13\x0c\xdc\xaa\xc4Q\xec\x9ecV\x04C8(1R.\xdb\xe63\xf0\x0e\xcd`\xf9\x9f|\xd3QI]E7;b\xddo\xfb\x8d8\x8bM'
        b'\xb4\xb0\x82`\xe8$\xcbG\xfc\xa7P\xd1g\xeb\n\x87\x05Wn\xad[\xdaH\x80\xff\xden\xc7Oo\x1f#\xad[,\x7f\xeb\xfe*3*\xf1~.\xf5N\x97\xb4\x17!\x96\x8d\x02\x83\x06\xe7\x94zY\xe03\x04\x0b\\'
        b'a\xfc\x89\xa5\xeb\x13\xa6\xfaz\xacP\x14\x89\xbe\xbd?\xc4R\x91\xd1\xcc\x0c\x96\x98#\xd4\x89\xb0\xc0\xdd\xa2\xfc\xb5F;\xf5\x83\xbc.qQ\x0c\xec\xa3\xf8\xd3wP\x10\xc5s\xafe\xa7\xa6UA\xac\xd0\x06j\xcb\xff\xff'
        b'I\xf3r\xe4\xb6\x90\x81\xff\xabTq\xac\xa7\xd0J\xbc\x03\xeba\x88=pt]\xea\xd9\xd7\x94\x1a\xbe#Xz\xf7\x93R\x94~\xa6\xf7\xad\xdci\xc3\xb0i2\x1c\x99\x9b\xc8\xe2\xadkP\x85L\x08\xaeal\xc8\x87\xf6'
        b"\x8e\xce\x80\xa0>$\xa3\x9a\x1e\x13z\xccn\xe5\xaf\xeb\xc0\xee\xcf<<\x02t\xe8\xbe\xd8\xbf\xd2D\x98\xc5'\xf3\x83\xe1\xbf\xe6\x06\xbbr?\xe2\xf4\xf4)\xe9\\\x14\xa76)\x1d)\xc6\xd0:Uln\xba\xb7/\x12\xf6"
        b'\x1b\x00w\xbb\xa6\xc1\x0b\xc4\xe17\xf9r~No\x91\xf6Dww\xe1<6d&f\x15\x16\xea\xf8\xf4\xae\xab\xacd)=\xb7\\\xe3\x8b\x11\xac\x18\xb2El\xd7\xdd\xca8\x92s\xe9\x0f\xce\xb5\xf6\xbbM\xcb\xf0\xae\xa9'
        b'\x15\xf6\x8a\xc0\xb3\xba\xb4\xf5\x18\xdd\x07\x9d3\xd5?\xd6X\x08\xed\xedm\xaa1\xe2\x98\\\x84\xf6\x99\x03\x815\t\xc6\x08\xd3\x99 \x98\xf8\xa9\xe3\x01w\xf6\xbe3\x17@\x83\xfd\xd5\x88|V\xf7\x9d\xc5|_\x10\x08Yv'
        b"\xba\xfc\x97\x1e=R Ik\x9d\x9c\xfar\x0f\xc4\x0c\x90\x1b\xe4=\xf7\x8fV.@x.\xd2\xff\x89j\x89\x08\xc2('\xeas\x96\xed\xc6:\x98\x17\x17jJ\xb6\xc4\xa1%\x0e\xb4\xf4H\xd8\xd9<\xf3y.\xe1\xbf\x8b"
        b'1Y\x88\xa7\x13\x9e%f\xdb\x15x\xce\x0b\xa9\x99\x07\x00\xb9\xf3b\xfa\x93\r\x92\xd7\xa4\x14\x81[(\xb5\xefr\xaa\xddE\x84\x83\n\r\x93\x0c\x96_\x10a[\x94g\xd9\xa5\xc6}>R\xb0$\xd2\xd7\x1a\xb2\x1c\x99\x86'
        b'\xe7\x06\xedE\xb1\xf2\xd1\xbc\xe38\\\xe8p5\xa4\xb1\x9b\xc2\x1cl\x04\x0e\xbd;\x8f.m7JeS\xf1\xc7\x95\xa4\xde)\x11r\x9248\x80]r\x86\xc4UL\x89\xd3c\xcc\xbf\xe2\x84\xab\ts\xb1\xb0\xcb\x86\xd2'
        b"\xde\xd1\xd0&O?\xe6\xb3\xf6\xeed\x8b\x03\xe1\xb5\xe7O\xaa\x9c\x95\x9ei\xf1\xaa\xfdO?\x84tE\xe6\r!\x07\xfb\xd1\xe3<:-)f\x10y\xc3\x06\xe6\x16\xe9\xa4^R\xb9\xe9\x7f5u?\xe1'\xa0\xad\x97R"
        b'\xc1\xd0\xd4\xba\xa6\x0f\xcd\xf2\x01,q5\x9fsFY\x15H\x01\xed\x06{\x16%\xb8#\xb3\xdc8\xda \x96\xc8\xfd\xbf<\xc3\xbb\x8b\xbc(\xf9V}\x87\xb0\x1bvP\xfd4]\xa1\x0c\x87\xf4En\x8c\xa1\x9bt@\xc7'
        b'\xcf\x92\x9f&6\xc4\xe0\xd8\xadf\xe2\xfb\x92\x91dcSD`\xbeI\x11V\x93\xb4\x0c\x82\x93\xe0\xe5\x06\x99k\xe6K\x97\x1d\xba(\xc0\x1e\xa2\x8dZ\xebP\xa6o#gV\x0c\xe9\x93\xea:\x11\x95c\x8a\xfa\xf5a\x8a'
        b'C\xce\xe2\xcd\xf9\x08RV!\xa5\xf3K\xecAX\x1ak4\x03_\xc3\x8ed\xce\xfd\xfb\xd8\xb7\x90\x97\x16h\xaf+1\xea\x99z$\xb9W7=\xe6\x08\xd6\xc4\x1b\x12wJT,\x9a\xe2\x14\x17\x98Y1\xfb\xa9\x08\x9e'
        b'\xeb\xbf\xb3\xc3`\x85\xf5\x94\xa4\x17\xb5sw\xed\xca :L`\xc2\xae1\x1eXN\xd3\xda\x85\x97\xb3\xb4\x9b\x8c\x01q\xab^\x94e\x16$\x87}\x19\x14^\x88\xe9\xc8J\xb6$Q\xe1\x99\xf1\x1c\xc2&5X\x0c\x12o'
        b'\xea@FD\tE\xc0\xeaj\xe7Q2\x88\xf0\xe7\xc4\x9br\x07\xd9\xf6\xec\x87Y\x9e\x12y\x93\xe5\xf2@-\xf2\xf2\xa4$\xf5;F\xfa\xe6\xb8\x91+hs\xdb\xac\xac\xd8\xd1\xb4\x18He\x03^\x80\xce!\xbe\xb1/\xc5'
        b']=9m|Bjk\xfcI\xf7\xa5\x9c\xa7\x97\x89\xcf5\xe6\xdb5HelK\xb0J\xb9\xcaV@Iy\x84\xb2^\xc3\xfd\x94Zs\x81\xf9@\xb3\x0c\xd1?\x06B\x0e\x8e\xdd\x08\xebnE\xf3\xf3[\xb1Y\xb8K'
        b'\xe0\xc2\x1d\x18Ui\x94l<\x9d\x08\xb1-\xc2\xb1\xea$M\xf5\x04\xd9\x96\xca\xe1\xd8P%)\xc2\x81\xdaP\xa5Qj\xcb\x11v&x\x15\xd3<\x1e\x85]=\x7f\x983\xf2\xf3;\xe6\x0c\xab\x90:>,\xa5\x1a\xeb"'
        b'\xb5\x18\xff\xfc\x07\xb1\xadVu\xcd\xac\xa9\xe8Y\xc5Ro\xe3\xb9\xb04\xdd\x19\xe4O\\>$\x18\xc3\x99\xea\xf9k\x18\xa6D.\xcf\x80\x1a\xb3\x9e"a\xee\xf3\xde\x96\xa9v\xb2*s\xb9Fbk(\x87\x04\xb4\x9c4'
        b"/'t\xb0\x95\xf4p3I\x8b\xc1\xd2)\xf5\x98\xe1n\xa89;\xdb\xb6\xef\x1d\x12\x93\xbc\x03\xf5\xdc\xdf\xe1\xae\x12D\xa4\x86\x00\xd3;\xc7q=\xd7\x19\x19b\xc3|X\xa8\x07?&E\xfc\xd7\xa2\x05!\xd1\xb5\x93m"
        b'\xe8\x17h\x10\x17\x95\r\x19\xae\xfeih\xa5\xbf\xdb\xc1\x93\x82Tx\xd8\xbd\xe8\xf8g\xe16\x1e\x17\xe3\x08\x8c\x81\x94:9\x05\xa6\xc0a\x02*\x92\xbbu\xfd\xfer\xe6\xd8(\x9a@1\xf5Ta\xd4\xdf-\x03\xa2\xc9u'
        b'.\x841\x17Uc\x9eA\xf0(\xe5\x82\xc3\x88\xc8\x08\xd9n\xfeb\xae}Ca\xcb\xc5\n\x9a\xe6\x1cS\xc2\xc0\x97*uP\x85\x9f\xfaorS\xa4\x15\x02\xf6*\xad^l\xd1\xb3K"\x05\xe6\\M\xb2\x11kvL'
        b'\xbf\x82\xa5\x00\x08\xcc"\xb2\xaa\x06%\xae;X\xde{4\xde\x0b\xb1\x95\xc5\xb4\xa2\xd8\x13\xa8\xa0Q$T\xd7\x11\x84"\xca\xa9omF\x0e\xe6\xdev"l\xd8\xf7\xb8\xfd"\x83\xe2/\xbf@\x94@\x97\x1f\xb2\xfd(\xce'
        b'\x8aD\x96`\xd9g\x1cp\xdflt\xcce7\x9bc=\x16\xc5\x90f\xeb2&/4\xb9\xd4Sg\xfaiU\xccL|z\xa0\xd7\xc8\xb31\x83l\xea\xe7\x1eT3\xd3\x01\xa0\x88`\x92\xde\x96\xa4j\xa7\xd1\xa6F\xcd'
        b'\xd3Sr\xf9\x87\xdf\xbeI\xa3;\xec\x08\xa0V\xb2d|\xe66\xdb\x03\xac\x1e\xb9U\xdfz\x12\x08\xf0\x15]\x8f\xb3\xaf\xfe\xe5\x9e\x9aX\x84\xc1m\x7fg\xba\xea\xde\xd4\x0c\xe0y\xcbg\xeb#\x06\xa3\xc3\xde\xdbz0\xcd'
        b'_\xec\xe7&\xa3P\xca\xcdl2\xa5:}\xfeHH\xf8\xee\x17\x90O{\x03\xa3\x1c\xd5\x922\x82\x97AF\xa0\x8b\x90\xe8\xd7\x06\xb1e\xa6\xbcd\x97\xc2*\xd4e\xdf<\xd1\x8f$\xa9|~\xc4\xbd\x04\xd5\x7f\xc0F\xd3'
        b'\x92\xc4\xbe{qmn\xc7UD\x16\x0b\xd6\xc1\x89:\x0b\xb5@\xcb\xa1ze4\xba\xf3\xfb\xb96\xach\x119\xf9\xbc"\x80\x85\x9c\x8e%\xd9\xd83\x8e\xa0\xec\xeb#\xe1&\xcb\x8f&\xe5\x8f\xe9/\xcd\xceTV\xb9\xe0'
        b'\x19\x12\xb3&\xbe\xcbw\xe7\rqi9\xcd\x03\xd8\xde\xfc^?\xed\xd0$\xc1\x8b\xefD\xe62\xc0\x1b\xf6\xb6 \xc8\x89\x08>\xf5\xa2\xedo\xf2x\xcb\xfa~\xb9O\x99\xc8\xb7\x9fv\xe3\xf4~\xb7 \x9c\xa8\x9b\xb5\x00Y'
        b'\x11\xe5!\xb6\x804T\x18w\t\xec8S\x91\xef\xee2\xee\xc4\xa6\x01@#\x9e\xc2O\xe3\xe8\xfd\x87\x03\x80\x1f\x8c1p\xf2BQlJga\x82Q\t\xb6\xf1\xa0\xd1_4\xd0Iz\xae^\xcceru\xe4\x8f\xcc'
        b'i\xc9\xdd\x04\xc2\xc5\xa5\xc9\x02Ay~\xb9\x10\x02\x81C\x1a\x1d\x96\xb1$\xd7\x1f\x07p\x0b\xae\x1e\xfd\n\xd4s\x05\xda\x18\xf4\xcbb\xeb\xb5m\x87\xc9m\x7f[\xe8\x86\xc7\xa3\xf5|\x8c\xcc\x95\xbf\xf2\\\xce\x1a+\x94\xc7'
        b'\xffJ\x16a\xda\x95x\x1a`H\xdc\xaaw\xeb\xcbC\xe3\xe0\x03d\x8e\x10=\x19\x8c\x0e\x1d\x178\t)\xc2\xd6d_f p\x1a\x90\x01\xf2}u\xe7\x1eWE;u\x06\x80:\xb1D\xc7\xd6\xf0\x80\x1f\x19y\xaaL'
        b"\x1f\xdc\xb4\xe9\x1c\xd2{b\xc6=\xba'QA\x8f\xf0Q\xb5\x13{\xb4\xe3\xc4\xe6*\x0fF\xe2\x0eO\x17\xfc\x94*\xdd\xbf\x88\xef\x8b\x9bt\x97\xb1[\xbe\x18\x8ae\xbb' O\xa0\x1c\xed\x85\x8c\x96\x08\xf6ly\xe1\x93"
        b'\xb5\xa6\xdf\x9bE\xf1wp8)=\xa2\x11\x08\xfd\xd8\x9f\xd9\xdd>\x82@\xc6\xd6\xdb\x15u\x9f\x00\r@?\t\x97M\xfd\xd4|`\x84v\xd9y\x89\xaa\x1a\x82w.z\xd7[\xaf\xc7(\x9b\xd7\x94\x93\x107w\xe7\x8e'
        b'\x92\x89\x116\x81\xcax\xca\xf4aIr{i0\x112\xcaS\xbfp\xf5\x964\x9c\xe1\x91\x12T\xbd\x12\x01\x16\xcc\x13\xcbL"\xd5\xa9v\x15$\x81\xbe\x17;\x1c\x96n\x95s\x87`\xd2n]b]q\xda\xab\rM'
        b"\xdc\\\x9f\xdb-)\x08\x15C\xe87\x9dxUJ\xda\xcc\x00\xf7z\x18\xa0\xd2\xa4j\x9b\x07\xbd[\x16\n\xd4\xaf?\xa3\x8cz6\xe8\xff\x91'e\xbcvs\t\x84\\N\x9d\xe3\x8c\xb6\xf7G\n\xe4\xf6\xba\x9b\xe5\x98\xfd"
        b'\x11\xab)\xa7\x8f\x00\x03\x88\xe0\xaco\x1b\xaepN1\xfdT\x02\xc2f*\xa5n\x98U\x97\xfb\r\x114\xbfU\xde?\xe0\x9c\x84\n\x82[4\x10\x889D\xc2\x08\x92O\x7f\xcc\x0e\xe9\xd9\x0b!\x14\xf36\xbc\xf9H\x1e'
        b'V\xfc\xd7\xb1\x87\xf2\xafG\x1f/aO\xdd\xefT\x17\xc2\x12\x8a\xb3\x1b\x81B?\xe3P\xc7M+\x05rXs\x97\xe7\x9d\xc3\xba=\x07m\x12N|\xd3\x99\xa5.I\xf0\xdfz\t\xee\x9a\x18\xf0+s\x00\x0f\xa7\xb2\xf4'
        b"*&\x11V\xaa\x93\xee\xe6\xe6\x97\x9a\xf4\x9f\x9c*\xe5\xc5'\x18\x9bM\x88\xd9(\xf2\x18.}\x84\xc2\xb9\x10ag\xd1\xad\xce\xca\xec\xed:\x92\x13\x05\xb1m\xe1\x01\xf1bm\x01\x143\xcf\xa6\\\xa5\x9bL)\xed\xe6]"
        b'\x10\x943{\xb6\xd3Mr#\x1b\x04K3(\xca\xf5\x90\xd7K\xa0h\xcbP\x85\x07\x048{1\x91oB\x13\x19\xc3\xdc`\xe5\x83\xa4\x15\x81pb/\x03\xe3:\xde\x18T0B;I\xe8\x02Y\t\xe9o\xba\xb7\xb7'
        b'\xaf\x00\xbf\xf3\xb9P\xde8f\x947+\x8c\x9b1\xdc\xd5gQ5\x95\xe9\xcf\xd0a\x92K{o\xc7\xe2\xd3`\xf1\x86\xca\xda\xde\xa4\xe3\xdf.\xdd\xf7\xd5\xd9\x97$\x03\x1b\xe9k^\xf7J\xb0N\xb9\xdc-\x94\xb1Z\xea'
        b'jn*\x02\n\xd5\x95M\xd1-\x0e\xa9dS\x9a/N;\x16\r\x1cw\x11R\xb9\xca\xf6L\x19\xc2\xef`\x0cT~1\xef\x1d\xf6\x95\xe7\x003\xb5-$\xf5B\xa1\xe04\x05P\xa0c\xfc\x9cx\x80w^\xdb{*'
        b"\xd8\xf6\xf1\xc8\xe2\x85\x9c\xefv\x17\x91n\xf1*\xfbR\xe1\xc5x\xc3b#\x0c\xf1\x1e\x11\x00)]\xef\xf0\xda\xa4BgP\xc1\xe6\xf6\xe3:\xcd\x94\xab\xab\x8c\xd1/\xeb\xde\\M\x93\xb1\x7f\xe3\x7f\x9d'5\x9616\xa0"
        b'\xeb~\xb7s\xfa\x8d\xd5\xae\x99\\P\xf8\x0cpN\x84\xa0\xd0\x0b\xa8\xed!o\x8fy\xe5\x7f\x82\x81jQF2U\x92`\x02\x04\x9f\x04\x9c\xd9\x89G1\xf5\xd6\x161\xc5\x93\xd2\x9b<\x1a `\x9c8e\x04,\xaa\xb4'
        b'\x90\xb4\xdd\xd9\x07\xcd\x1b\xfb\xdd\x107\xb4|_\xa5\xe4\x9dT<S\ri\x9f9\x13b\x86s\x9ea\xe2\xed\x82O>\x16\xd6\x9d\xa4K\xe0$\x84\xd6\xb5\na\x03A\xfb\xf1\xb30j&\xd4\xdc\xfb>\x9a\x10\xackC'
        b'\xc0\xf6\xd8\xb6r\xb8 \x00\xc2B\x17<\xc6\xf1RcN\x14?+\xf2\x8a\xfdu\xe8\xf4\xbfz\x8dw\xc4E\xdf\x10\xac\x19\xfb\x94\x8b\xc8\x81v\xc4\n\xd45m\xfc#.H\xb5\n\x94<\xee\xbf\xd5\x83\xc3#\xf4Q\xfa'
        b'6\xc3\xc2\xde\x9d\xb8\x0e\n\x89V\x86-\x9b`\x93\xa4*\xd9\xcew`\xf7\xca\x9c\xf5{\xa4\x84NM<\x05A~\xect\x16H\xa6\xab\x98\x0e\xbd\x8f\xf3\xb6\xb4\x08\xbam\x14\x12\\\xb0\xa90xB}Saz\xd1$'
        b'H\xd9\x87\x00\xbc\x96/\x0e\x14\xd51\x8dJ\x85\xe3\x99\xde\r\x9f\x04\x10*i\xd9\x80\x83\xdbf-\xcb `6s\xce\x82t}\xbco:\x9c@\x0b\xbd\xfb\x81&8N\xda\x9d\xe0\xa8\x0b\xca\x8d\xba\xf6\xae\x80yN\xb4'
        b'\xf1J\x92\x97\xb9\xa4\x89\x0f@(D:L\x16\xbc\xbbQ\xb3\x17\xd1\x9c\xac\x15N\x88\x88\xe5U\xf6\xc4\xf6u\x80\xd8\xdd\xf7+jX/\xeeWwFCt~6\x90\xc0\x1c$\xf7F\xc8\xbc\x91y\xe1\xcdT?kp'
        b'\x8e\x9f\xb4\xdd\x06\x1d\x02\xe2\xc4\xaf\xc9\xac\xef9\xa8\xd8\x97\x1f\x19c\x1c\xe1\x85\xac\x1f\xfe\xac\xb1\x89\xbb_O\xf4\xbb\xb9-i\x88EL\xec>+\xfc\xd2\x06/\xfegmM\x88/\x91\x1a\xf0~-\xb5\x16\xcb\x84\xa8\xe1'
        b'\x99^\xa0$\xe2B\xb8[\x05\xb4\xb3\xed@\x80r\xb9l\xe2E\x13\xc5\xab\x87<\x1e\xa7l\xae\xd2\xb6\xd82u\xef\xf2\xd8)[ T\x9c\xe9Fh\\\xbc\x08\x01x5\xc6\xc0\x06\x9b\x00\xb4\xb0Y\xe0\xd8\x00\xb8\xc0q'
        b'\xa7\xf3Sa\x06\x86R\xc4g\xd9\x14\x1bs:\xc9\xb8\x89m\xe6\x01\x8du\xd3\x1c\x9fx\xcd\xd7\xd0a8\x9aZ\xa1\x18s\xc6\x94m\xf6|\x19af\x11i4\xed\x18S\xc4\xac\xd3e\xe5\x04m\xd0\xe3\xf7\xddd\xb6#'
        b'w\xfb\x832Q\xd5\xfaI\xc4\xeaU\xc9\x06\xe6{\xd2\x8bV\xe6\xaf\xfdh\xd7\xa7F?\xd0\xc95\x10\xf6\x9d\xe1\xb3Z*\xc7g]#^R\x91\xae\xcb\x1f\xf8\'\xb0H\xc4"\xf7\xa2*\x18\xf4v#d\\\xe5\xf7\xc6'
        b'\x1e\xc4=w\xdec\xebF\xae\xdb \xff\xe5\xfeL\x87\xce$\xfd\x13\x98kM\x9b\x89\xfe\x12\xb7\x84\xe5\xa6\x07\x1fw\xfc\xcd\x03\xd6\x94\x97\x96\xf8\x8c\xf9\xd5\xcf\x0c\xd8\xaer%@s~?\xa4\\\xac\xb0\xc6c\x93.\x95'
        b'\xb4}\nR\xe2U\x1ck\xf5\x15\x9cM\xf1\xb9\x1eP\xa3\xfdA0\xc16\x93\x9a\xe4}\xb4+\xd5\xd7?\xb0\xcf\xae^\xfb\xab\x9aa\xe6\x19\xc9\xf0K\xe0\xa2\xb9A\x8d\x97\xf6\xfd\xa0H\xeb{u\xc1\x13\x8f\x18a\x8d\xaf'
        b"\x97f\\\x18`[[\xbf\xc4\xe7P\xc9\x87\x82\xe7\xe7\x89\xb2b%(\x13\xf1\xac\xc6\xad\xac$.\xeb\xcc\xfcIX\xfd\x10\xc1\x8cK\xffbq\xa4_\xcd\xe0T\xb2R'\\jU\xfc_\x1f \x81\x8d,\xec;\xe0\x1f"
        b'D\x91\xe5;x\x92\x86g\x13\x8a\x1dl\xc6\xf8\xd5=\x9a\xe0Zw\tV\xec\x81\xe3:\xf7\x1b\xb80_\x01\x84]\x9f\rk\x12MD\xf4\x17\xbb\xde\xdf\x13%1\xf7xm\xe8b\r\x0b\x98M\x0c\xbc_\xa7q\x16\xa5'
        b"\xbb\xd3\x80\x8eq\xc1\x00\xe15\xbd\xfe/\x96\xe2\xf3\xfa'DF\xdfG\xd6,\xfa\x0b\x95oD\x925\xf3_u5\x19\xc6\t\xc1TI\xaf\n_\x07\x8c\xf9\xc3A\x98W\x10 WA\xf6\xe8hs<6{>\x99\xe8"
        b'n\x9eo\x15m\xc9j\x12\xaa\x803\x8a\x94m\xe0\x17\xa8\xfb\xb3\x9d\xb8c\xea\xf2\x99\xde\xda\xc9m\\\x06\xf3\xc1Jg\xa4\x05p\xbe\xd3d\xdb\xaa!\xa1O\xaf\x0f\x04\xb2K\xd4\xbdQA\x01\x17-I\x06[\xed\xcb?'
        b'\xd0F\xa9\x0c\x1f\xf2l\xe0\xb94\xd8\xe8\xb0\x84\x85\xe1P\x01)\r!\xd4\xf4\xd1\xf4\xbd\x83\x91Eu\xdfEle!\xb3*<&\x01\x89\xb4B\x1e\xc3=\\\x10\x19X\xf3\xe7\xc2\x916\xd9\xcf\x9a\xa9\xd4K\xda\x95X'
        b'Fv\xb2\x14(\x19ghR\xa6\x18\xa9\xe8\x8f\x9d6\xf1\xb3\xa6\xc8n\x91W\x02H\xa5\x8c\x03\xd9,\xd51Y`s\x14\xbct\xafZ\xb1N\xca\xbc\xe6\x06\xc3\\\xaaIu\x8f\x99\xb6u\x8a\xd6\xae~m\xf3\xecN\x11'
        b'P|L\xf9H\x84\x1d\xfe^\x0cn\xa5\xe6)]`\x92j\x81\x9e#}\xb5\xbb*\x03\xd5\xb2\x7f\xa8Q\xb1\x95C\xbb\xf6$d[\x95%\xd6\xf4\xb7\xba\x92J\xdd\xc6\x83\xa7\xe8=\x97\x82\x8a\xf3\x99\xff\x96\xa2c\xcd\x17'
        b'~\x9dnc\xa5P\x81.y\xab\xf0<\x04GZ\xefH\xa6\xa3\t\xec3\xf3B\xb2%w\xed;\xa7\xb9\xad\x0b\xc9R\xbe\x150X\xe8Q.\xd79k{X\xf5\x01\x00;\xb0\xde\xd4\x05vV\x95\xd7\x17\xb1\x19\xcb\x03'
        b'*\x92\xfc?\xfaEA\xf4\xf5@\x04\xd1\xa2\xe0\x80\xe2:\xb3\x91\xb3m\xa2\xcd\xf7\xacF\t\xef\xa5\xe2\x04\xfdp\xf8\xc1k[\x1d?bpX\x03\x06G)\x0fG\xc4\x05"@\x12X\xdb\x90\xd0\xe2\x03\xc1\x02\x99\x17\xd0'
        b'\x08\xba7\x1a\xd4\xa8Dh\xe9#zR\x93\x9f\x96\xf9\xa5`\xcc\x14\xa1LSg\x84>0y\xb0\x05G>\xdf\x86\xf2\x87y4\xabj\xbb\x0c\xdb\x9a\xdd\x10\xaauAM\xb1\x1fl!\x01=\xb3\xf9\xde^\xf7\xf5\xd3&'
        b'\xb79\xe6\xda\xa4$0Q\xe8\xc5\xb6\x9a$\xbd$\xc6\xd2\x95\x85M4-\xae\xe4E\xceW\xca9}\x89G(\x1e\x85cGb\xfe\xb7\x97\x99\xf1\x9bC!\x80lr\x95\xc5\xbd\xc0\xa1\xd47\xb5Q_\x9c\xf6X\xe9\xa5'
        b'\x98\xdc\xd8E\xb1 \xd9\x84J\xadc\xd4\x0c\x12DH\xe1!\x99\x1a\xdd:\x95-\xf4\xac\x16\x81Y\xcf\t\x0c\x9a\x93\xf9>\xee\x18\xd8\x91QP\x83XQB\x16S\xf18$B\x95\x95\x87\xdb\xa8S\xa17>}\xd0\x05'
        b'\x1f\x15\x8e\xcbS\x18\xeac\x03\x06\x1f\xf1\xae\xe1C\xab\xa3\xf8\xe0T\xf7\xba%\x08p\xb1\xcf&\x87\xc3\xd1\xe5\x1f\x8b\xf2ux\xc9\x00\xa6.\x9e\xbd\xfc3\xcd\xa8\xfa\x17\x83]\xe6~\xa6d\xaf\xcc\xb7"=\xd8O\x19\xf7'
        b'\xfa]`?JV5\xe2=\x01C\xce\x82\xc3W%lB\xa8\xbb\xe1W\xeec<\xe0\x8e=\x03!\x94\xfbk\xccX\x0b\xaf!\xb3\xdd\xf4\xb4u\xc8\xd64\xd0\xadW\x0f\x8e\xc2\xfc\xc3\xa9Z\xea\x1a\xb0-0\xf2-p'
        b'it\xd35{\xe2\xb1\x90\xc1\xaa^{\x0ez[\x15\t\x9e\xd3\xd0\xf1I\xea\xa0!\xef!\xf4\x97\x04\x8f\xccA\x14\xf5Y\x9a\xcb`#\xfdT\xa6\x07\x88\xdfP+%9x\x85\xc6\xbcK\xcf\xa3\x7fq\x19\xc1!?\x05'
        b"\x92A\xe6\xc6f\x115\xfcdR'\xa4f\xbb\xc2~X\r\x8f\x17\x8cQ\xfd6\xc5\x88#\xfc\xf4n\x06\x07\xbbg\xa3\xbe\xf4\\k\x86j=@+a\xc3\xb4\xc7\xe7\xd6\xc9\xcd\x8d\xc3\xac\xa6>\xe9\xc8|\xaa\xdc/\x08"
        b"g\xd1b(\xd6\x88Cd$\xedd\xe0\x8e\xe0$\x10\x0f\xd6jbCG\xb9m\x14QA\x1e\xf5\x1b\x10\x98L!'\x9d\xe3\x94\xbd\xb6!i\x04\xc2\x7f\x85\xc8\xf0,\xd2\xc6\xfb\xa4>\xbc6\xcc\xdd&\\\x1d\x00`J"
        b'$\xe2T\x9e\x9f\xd27\xe0\xfej\xd7\xd8\xdc\x16\x94\xe6\tLu\xc9,>\xe0#!p\x15$~\xb7\xdaWM\x96\x89\xc5Uzq~C\xc6\x07\xbf\x99\xfe\xf2@c\xf4\xf0k\xfdZ\n\xda\xd2\xd7\xa3d\xacz\x9f$'
        b'S\xbb\xfe&\x89\x18f\x07uN\x1ev \xaa\x9e-i\xf57\x1b\x8c\x82\xc0\xc9\xd05)\xbb\xa7\x83\xd5\xf3\x86#U\xdc\xd5E\x97{\x03\xed\xa1\xd8I\x03\x9b\xec\xac\xb6`\xc0\x13n\xe1\xf7\xf9.\x04vV\xcf*\xcf'
        b'\xf6"\xaaH\x0c\xa5\x91(;=\xf9l\x90\'\xed/I\'K\x7f\x86\x1f\xb1\xf19\x9e35\xa1\xcc\x0c9\x88\xe5\x9c\xf9N=\x97\xf1\x14\xad\x00\x06\x12\x15<\xd111[\xfa\xcf^\xb1\xa6\x13\xd1\x9dCTJ\xa5\xda'
        b'\xe8\xea\x02n\xd6|9VZ\xf3\xe4\x80H\xab\x81\xeb/\xf3\xfd@\xb7\xb0\xca\xae:\xb5\xcd\x9ds\xcfD\x8c\x83]\x08\x83\x87\xa8E\x8f\x1d\xd5\x8e,\x84\x92W\xb7f\x16\xb2#P\xc1\xf4\xbf\x05F\xcc\xb70O\x8f='
        b"(m\x887\xbd,\nJT\xb9\xf7\x8eKN\x1e\xf5\x9ce\xf2\xd0\xc2S\x9eX0'9\xad\xc6\xce,\xa2\x13\xb0\x90E\xf1\xfc\x8bI\x1d\x94\x85\x87=\xa7\xf5z\x9c\xe2p\xc8\x0b^\xe1\x06\nh_\xc0@y\xe4~"
        b'B\xe8\xfa\x00l\xf3n\xa0\xbfYjw\xe3\xc07m\xf2\x9d\x84S\xee\x94<\xd8\xbd\xc8s\xc0x\x8e3\x0f\xe6\xa0\x10\x85\x16\xe1-0\x8de\xa7X\xc2\xd0x\x88\x02\x02|_\xc7\x05\xa4y\xa8\xb2\xc0\xdc\xd2m\x89<'
        b'\x02.3\xb3o\xda\xfc"\x86~\xdcX\x16\xc6\x92\r\xfaA_\xb5\xac\xcf\xbe\xdf\x80\xe6\xb8\x11VI\xb4A\xe3/\x1cr\xb2\x9c^!\x99{c\x87\xccsx\x1c&\xca\xc5\xef\x00:\x97x\x94R\xf5\xb4M\x16\xf7E'
        b'\xaf \xdd;Jo\xa0\xa1Zz\x9f\xfa\x19\x9a\xb3GJ\xca\x93\xb1\x98q\x06\x1a\xcf\x05n\xf2(j\xa4\x9a\xf2B\x0b\x0f\xe3:\xff\x80\xaf\x10+\x935:U\xca\xc0vH#$b\xfbKg\x83\xac\xb0e7r<'
        b'y\xcfy-\x95\xeb\xd1\x8b\x82\t\x04\xe43\x06X\xef\xb5\x1e\xe1\x00W\x192mM\xa24\xd1\xc3\x84\xd5\xcc\xb1h\x9dP# =84G#\x17\xae\xa3\xec\xdd\xb6\x08>E\x89B\n\xc0s\xc2N\xfeT\x14\xb9.'
        b'\xa0\xc6<n\x14\x12\xebr\x052\x8b\xd1\x06\x93\xd7O\x96\xd2\xe3\x8cj\x95q\xe6C\xd4\x19^-\x1a\x05\x95\xae\xe3\x15N\x07\x84\xce\x1b\xf1D\xad\x19\\W\ry\x17\x89\xc9\x17\x7f\x83\xdf\xfb\xb7\xcf\xfd\xec\xcar\x90\x85'
        b'v\xc7Ty\xa0(\x80\x8c\x11\xaa\xf8+\x9b8x\xf8\xbf\x1dE\xaa\xaf\xcf\xdf\x01S\x19a\xf3\xe7\xac]\x9dpt\x15\x96\xdd\xd9*\xfa\xf11;\xd3-\x19\x98\xa0bM \x85O\xef\x9e\x03\x9cg\n\xa5\xd8z\x1b\xd4'
        b"t\xe9\x12\xa1d\x03\x1d\xc83{o\x13g\x97>\xde\x08\xa1\xda.\xd5\xee\x9cT\xfb\xc4.\xa4\xa7\xe3\xa2\xcd}\x08\x86\xc0j1\xd4z\xfaGH\xa4\xfa\xde\xd7\xfd'\x8f\x1b]\xe6\x7f\xf8\xc7\xc5\xdfa4\xcb\xbf\xa19"
        b"v\x06\xdf=\x1d\xcc\xa8L\xc7\xebK\x82]\x0f\xa5\xaa\xcb\x86\xfe\x15Y\x95\xaa\x7fa\\_\xc3\x07\xe8\x15(\x87\x90`\xb4\xfa'\x03UC\xc6\xd3s\xfd\xfa\x92\xff\xa1\xfd\x86y\x9cq\xe3\xf2`W\x0c?A=+\xa0"
        b"'a\xd8\x9eU6t\x89\x9e\xdcWX\x83\x9d\xa0'\x1d/\x19\xcch\xb8g4\xca\xc9\xeb\xc7\xe7(\xcc[\xf2u\xf2\x01\xce\xcb\x18\xa8\x16\x81\xfa\x87\xdfv\xbc\xc9\xb5-\xf4\x9a#\xa9i\xc6\xceH\xd5\t\xd8\x0e\x10*"
        b'\x0cq\x04i\x1d\n+N\x1c\xacl\x03x,E\xa6r\xd7O\xabQ\x7fN?5\x199\x82\xd6\x06\x8e\xeb\xfc\xda\xc9!\xd0\xa9a\xf4\x12\xd4I\x0b\xb6\xbc\xcb\x0c\x01\xd3&_\xb6\xfe\xf2\xf2#\xa9\x1f\x1f\xc1\xd5\x8ck'
        b')\x00@*C2\x92=\x84-A{F\xa0\xc5\x88A|:\xcd\xcaW!\xcd-c]\xc1\xba\xcet@\xf6*+\xf3\xa5\x88\x11\xdd\xbc\xbe\x97L\\\xe7\xf3\x96\xdam7\x8d\xd8\n\x95\xb7\xe63EE\xe3m\xe6\xea'
        b'\x87\x99\x08\x13\x1e\xadDt\xe9k \x18s\x93\xc4V\xc3E\x8a{\xf8\x1fG\x1d\xf1\xda\xdd\xdf\xb4\xdf\xf8\x87\x18fG\xd1\xf47\xa9\x944\x04\xdc\x99A\x86e\xbff\xf4\xca\x15\x08]\xbd\x96\x08\x04\xe3\x9e\xee\x94\xf9e'
        b'\xb5Y\xf9\xf9V^\x9f\xe9"sp\xa6\xfc-\xa5Y\xb8\xc7\x99\xf3\xb6}6\x0f u\xc8S\xaf\x0fj\xe3 e\x1b\xbd\xf1\xe2I<\x1f\xec\xaa\xd8\xdf\x82\x94\x00\xe3}\xf4\xea\x06\xc3EpxJ\xf4\x93\x9dy\xd5&'
        b"\xb9{\xdaA\xcb|\x9e\xe8\xc5'\xa1\x14\x86\xf8\x1f\xc0\xc2\xf2\xdc\x17\x86\xfa\x8a\xa6\xad\x83-\x91\xbf1\xf9\\]\x19Z\xe4\xcb\xd6H\xbdb\x9eUL\x1d\xd1\xad\x1fz\x1a5\xe22m\xb4p4_.\xf3\xc8\xb6c\xd6"
        b' \xabo\xa0\x02\x11F\xb3\xcd\x08\xe8\x8e\xe5\xacb\xe8dgH\xb7)\xb3\xd4\xab\xa3\xd3<{\x96\xef\xc8\x8d3\x95x\xaf*g\xba#a&Z\x1aM$\xab\x1d\xe1#2\x05@Z\xefQ\xa0DU\xa2k\xc3Fy'
        b'U+MQ\xe6\x17t\x15\xbau\n\xeb\x7f\xear}v\x91S\x844\xca\x84\x80^\x88\xa8g\xf6W\r=\x1d\x19\xd2\xe7cp\xc9&\xa8\x9c\x19E\xf9\xfa\xe7\x04h\xe5\xdf\xcf<\x8e\x16\xe3\xff$\xb7\xae\x93\xae!{'
        b'3\x18mP\xc5\xe8uE\x9e\xc1v\xf3\xfb\x152A\xb7"J\xc4\xc5\xb9s\x93c\xbex\xc2\xde\x1d\x1a\xa0\tKMW\x8ct]\x94\t\x964\xc5\x15\x8c\x95 \xe3,{\xe2\x88|\xf8&\x92\x89\xb3\xd4\xbf\x89\x1d\x8e'
        b"0\x99qW\xd2+\xa1O\xc7\xb5\xbcH\xc5WT\xa4\xb3\xb9\x0b\x1e\xfbj\x8d\xa9\xc5\\\xa2'\x0e\x7f\xc2\xc5TM^'K\x9eD6\x85\xe4Z\xe2\xfb\xf9\x11N\xf1/\xe7M$\xb9\x9f\xf8k^]?\xbdd\\\x99"
        b"jgd\x90P\xea\xc9\x14N\n\x04\x9a\x8bL$S\xde\xb8>\x80\x9b\x18(7<t\xaf+\xe3z72\xde\xd0\x19O\xfbv\xfe\xa5\xec'7\xa8\x0c>s\xee\x99\\lX*\xc3\\\x8aQ \xfd\x9c\xba \xcf\x86"
        b"\x1e\xea\xa6\xd6\xbd\xb4a\xceLJ\x01\xeb\xb0\xb01\xcf\xf8\x98R\xef\x11\xdb{\xfe\xc3\xbf\xa7\xee\t\x186\x84\x18\x9a\xe8\xb1\xcd\xab\xfc\x0cUu\x7f'\xc1<_\xd2\x9ci\xd7\xab}X\x86\x9bsKQs\xefU\x97\x03"
        b'\xd6\xe4\tW\t\x11\xfa\x82\xcc\xc5\xc7V\x83\xd1.u\xd4}\x92V\x06\x81\xd9\xd0\x8f\xf4\x85\xdf1G\xd2\x96\xc4\x96@\xb0;q\xc9\x8b\x01\x01\xec\x14:\xc5\xda\xe9\xa8\x14\xb52}G}\x03\x1c\xe93\x1a\xe1\xc8K9'
        b'\xcb\xf1E\x8b\xad \xf3\xc9@V\x9a\x836/o(\xea\xc7c\xb5\x8a\xb6I\xac<5\x17\x91LBP4\x8fm\xbe{ \x1d~\xd9\xd8\xd4g\xad\x9e\xddi:\xda\x8f\x84\xd6\xccn\x1d\x9c\xff\xad%\x8a7\xc9\xcf\xc5'
        b'\xa2I\x95@ZS[\x96\xa8\xa8<3GA\x01\x98@\n\x10\xae8\x9a\xa9\x1f.\x02\xa7x\xc1\r\xb2\xf8\xa2\xa1q<\xba\x98\xc8\x8b\x81\xd4~!\xbe\x0c\x99E\x0c\xf2\xf1gG\xc9\xb1\x0c\xbel$<\xffyx\xd1'
        b"\x10o\xa6\xb3\xbd(\xac@\xca\xd2\x9c\x0f\x83\xfe\x92\x10'\xb5\x05\x11M\xe1B\xf7D\xb5\x16\xf1\xabO\x13\x87\x01a\x11-\xb9~\xbeh\xbe.\xa8\xc96\x10\x86\x01\xea\x13\xbd\xa9\xafi\x90?o@s<iz\xf4\x04"
        b"\xbb\xa5\xe3K,\xca\xb3\x95\x8dlJ\x06Y\xa5F\xb9e\x97\xed\x8e\xca\x91\x04{'\x91e\x84\xde\x99\x8b\xfe\x083\xea\xf7\xe0\x98\xa3VD\x07\xde\xb6\xbfl\x9b#`\\\xeb\x1d\xfe\x9a\x9c\xad\x15\xe7F\xdaV\xbd\xcan"
        b'\\\x92\xc04\x87+\xf0\x8bO\xfb\xb4\xe3#\x90A\xb4W\x18\x03\x1e;\x8e\xb9::\xa23\x083X\xab\xdd\xb6\xb3\xe1j\x8a*\xc7\xabPK;o4\x02{|/\xf4\x81\x96y\xea\xea\x0c\x12Azi\xf5\xed"\xa8'
        b"\xe7\x08\xceh\xd6O5\xe78\x8d\x83\x99X\xef\xa3\x1bU^\xe7\xef\xadr\xb6'[\xa7o?\xd1\x0e\x87\xad\xc8\x87Eo:x\xe1\x94\xd2[\xe2\x88\xab\x92{\x1b\x10g\xdaW?\x18d:\x9a\x91\xd4\xa9l\xfa\x7f\x8c"
        b'&!\xb3V\xb5\xa2, \x92\x0e\x05\x9f\x16\xb8\xb8\x16{\x9d\xbb\x00\xf3{L\x92\xe9\xf3\xacw\xbb\xb8\xe49\xfd\xba\x05)\xfd\x80\xd7\x86\xbf\x16a\x90\xff\xe98jO=x\xc8\xb2\xbf`\xfc\x9aTn\x82\xb2\xe1gh'
        b"\xd8l[}\xca\xa0\xb9\xb1\xbe\xe1\x9e5L\x980{\xbf-)75\x84l9\xa8VG\xb3G\x82\xa4\x04\xde/\xfa{\xe9\xb3\x89\x99'\r\xfcd\x91\xaf\\\x93 \x89\xcb<`&\xf1\xfa\x97\xb8\x0b\xee\xa4[k\xc6"
        b'\x14Iz2\x84|\xf4\xab\x17f\xf8\xf7\x19\x89\x7fV\xaf\xa5\xden\x1aA}\xde(9\xee\xf2\x7f(\x0bu;\xc3\x0cc\x1c\xcc\x10\x14\x91\xbc\xc3\xf7\x15\xab;f\xef+a\xa3-\xdf.y\x1e\x17\xac0\x17\x9f`\xbc'
        b'*3\x12~q\xadg\xe9\x169\xdd;\x9f\x10*A-`\xbc\xdf\x0c\xd6b#\xed\x82\xf0\t\xb5]-\x0e\xcd3\x0b\xc3\x03\x94,\x11\xc1\xf0\xd3\x04\x0e\x9c\xce~\x16\xe4\x84\x0c\x15!\xe1k\x1a\xb0\x05\xef\xe3\xf0\x02\xbd'
        b"\xde\xef\xa7c\xacd\xda\x88\x17bJ'\x87\xe9\xd0D\t\xb5\x907\xcb\xdd\x968)K\xb6\x194\x0e\x88B\x99\xc7\xf2\x1a\xa1\xce\xaaT+\x00DT\x14\x9e\r\xd9\xe4\x8e\x06\xae\x82\xca\x01w\xf2\xd5\xcc\xd9\x91\xe3\xcb\xa5"
        b"\xa2zO\xe3\xb1\xc4\xb6\xcfg\xc3\tr\x0c\xfe00U[\x8f\xf9\xc1\x9e9'\xd0\xabU\xc6\x1aC\xaan\xbf\xf5\xad\xf9\x9d\x96\xc3\x1c\xa3\xbb\xe9M\xdf\xe8\xac:5\xd8CyT\xbd\x07N\xa0<6o&<=y"
        b'7G)=\x04H\x81\x07@\xc0\xa2\x9b\xa1t\x0f\x16\x06\xd3\xcc\xe6\x90T\xf0\x8e\xe7\xfa\xe9\xa6X\xb2\x8c\xb6\xa1\xbf\x07\xa0\r\x9elV\xf5\xab\x1a\x9f\xc5\xad\xd1\x9f\x0e\xdaF\x96\xac\x07\xaa\x0b\xbdN\x08\xb7\xfe\xa82\xbb'
        b'\xf4Vys\xa8\x0e\xaa\xa7\xc7Y`\x96\x9c\x86\x19\xd7\xa2\xa2G\xe7r\x1eH\x87\x01\x80\xc6\xf9\xb3\xe2\xb4\xbb\xbc\xdc\x9dq\xe6r\x8b\xdb \x8c\xe8\x90+\x90I\xe8\x00\x1f4\xc8\x1b\x07\xf4\x18\x18BX\xcc\x8b\x8e\xce\x02'
        b"\x1a\xeaK\x83o\xd1\x1b\r22\x9cnB\xb5\xdd5e'\x12?\xc1,\x80\x99\x02Z\xc9\xdfsT\xa5\x12\xa1\x1e\x7f\x06\r\x1f`K\xfe\xd7'\xc4\x16\x80\x171\xdd\xf6\x12?\xba\x87\xed|V\x88\xd6\xfd\x84\xc0XH"
        b'2FZJ\xfb\x04\x0c\x92lH\xe2\xf2\xbb\xc5\\\x17A\x8dH\x03!\x15Q\xb6\xf9\xd1\x92%?\xc3\x04\xfa\xe3\xd5\x1e\x06\\\xb9\xdf\x8eo,9\x91 \x9e\xbd\xec\xbc\xe3U\x1e\x9a\xa9\xf9Y\xce\x0b\x87\xf1[[\x99\xb8'
        b'\xde\xf8\x83\t\xe0A>7cE\xf4\xa0\xa3\xf4OcA?\xd9PR\xbe@>\xbf\xfb\x0eV\x8f\x05.\t\x9c\xe4i\xd5\xddZ7\xef\xa2 \xfeKw\xb0~z\x94\x88\x8e\x00\xe1\x8706\x95A\x04\xec\xc3\xcd\x99\xe7'
        b'<\xf8\xb3\xa8(F.\xa0\xbek3\xccX\xb6i\xf0\x04\x80^^y\xf2\x7fv\xc9d./}E\x1a\xd4\x7f}w\xa6\x0f\xe3\x02\x84\x1b\xdc\x88~yFG\xb3\xf7\x16mZ\xc4l\xd3E@\xe1\xe8\xec\x08\xbdX\xcf'
        b'\xaa\x88\x1d\x87\xc8\x9c\xe3{\xd0\xd7-\xf4\xdd)\xaa\x1a\xcf\xab\x9d&3\xafHh\x98\xa6Z\xb0\xd2lc>\xcf<\xba\xae\xa5\xb4\x1bX\x97\x0b\xbc-\xff\x91/\x112,\x1b\xcf6\x10\x1ez&\x8f\xc5\xba\xa1\xe6\x11`'
        b'\n#8\xf1\xc4\xe4T\xf9M\xce\t\x0c\x0e\xef]\x9b\xb4\xc9\xed(\x10\xaeU\x9a\xd0D\xc7a\x1fjj!\xba\xc5EP2E,)\x1fm\xad\xf6\xe3\x98\xa9Zyt\x90\xdb\x1a\x12f\xf1\xb5\xf7\xb9\x87,LZ\x14'
        b"\xed\x95t\x921:=|\xf8\xb1'\xd7C\xb4\xe4F\xdf\xf6\xd0\xb1O^[\x84\xaca\x0b\xcbb\xf2\xb1K/\x9f\xcf\xc9J\xa0Q\xa9\xa9\xaah@rb\xfe\xe4c\xc5v\xc3\xee\rm\xe6E\xd9<\x0c\x81\xa5\xd7\xcd"
        b'\x0b\xb1\xc7AG$i\xd4M\xcb\x81Q\x10\x0cr\x08\x18\x01.\xe8~\xd4Z\x07\xb8\x11\xc9!M\xc7N\x84E6\xe8\xe01\xde\xe5J&\xdc\x9a\xaa=\xa8\xbc\x02\xa9\x87\x9dQ\xf5\x8f\x01H\x02+\x8d\x99\x0c~\x8f\xd8'
        b'\xf8\x8e\x11eZ\x13\xf7\xc1e\xe2~B\x87\x1a\xbf\xe8C\xa7k\\\x8f\xf8\x920\xf1\xde\xacT\xeb\xc6\xb2: \xf0\x02\x0fT\xe95\xbd\xae\xbf|\xb4T;]\xbf!s\x9ez\xfa\\~\x0c\xa7\xa5\x96FJ\xbc#r'
        b"\xd7\xa8'\xbd\xb3w\xa1c\x932\xf9n\xd2\x90\x1d\xa5m^\x88\x01\x13Q\xae\xc2\xc5\x08\x97>q\xd9P\x95\x9f\xffF7\x89UF\xa6$\t\x14\x10\xd3\xfe\xad\xeed\xe2\x8fQ\xf1NBSJ\x87wT\xb4u\xcaQ"
        b"\xb0\xa5\x8b\x9d\xe5\xdd\xd5LO2\xa6\xe3\xb0'\x1a8\xdc-\xc4Mh\xc2\x94dv\xf8\x089?\x1b8Uu\xec?\xd7\xd6\xf5\x1a\xd4\xa3\x04\xdc\xf5g\x17\x95\xa4\x0b\x1b\xc3Z\x95\xbfS\x07\x96\xb2/_,z\x04\xb7"
        b'\x8a*?\xeb\xb9\x8edTJq^\xc4T\xe5\xc0\x9c\x0c\x00\x13v\x1fm\xdd\xda\x87\x15\x009\xdf\xc5\x87\xfd>\xad\xcf~\xa0\xf5m\xbb3\xf9\x95\xbf\x0b\x7f^\x9c\xe3\xeed\x88\x8daS\x83ko\x11\\\xcer\nT'
        b'\x8f/}\xfb,0\xf1yT\xa6\xf9\xf2"Z\xcd\xba\xee\x95\x86\xf7y\xf6\x10"\xb0\x82l\x05*\\\x80\xb7J\xd0\x07np\xad\x10o\'\x9d\x8d}hr\x8cf\x0f\x007\xadh]n\xa3\xd8\xe2\xa6\xc4\x1a\x15*\xe8'
        b'\xf3\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r'
        b'\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
